===============================
networking-ovs-dpdk
===============================

A Collection of Agents and Drivers to support managing DPDK accelerated Open vSwitch with neutron

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/networking-ovs-dpdk
* Source: http://git.openstack.org/cgit/stackforge/networking-ovs-dpdk
* Bugs: http://bugs.launchpad.net/networking-ovs-dpdk

Features
--------

* TODO
